@@ -80,7 +80,7 @@ use common::sense;
 use Exporter qw(import);
 
 BEGIN {
-   our $VERSION = '2.0';
+   our $VERSION = '2.3';
    our @EXPORT = qw(
       IN_ACCESS IN_MODIFY IN_ATTRIB IN_CLOSE_WRITE
       IN_CLOSE_NOWRITE IN_OPEN IN_MOVED_FROM IN_MOVED_TO
@@ -123,14 +123,18 @@ sub new {
 
    return unless $fd >= 0;
 
-   bless { fd => $fd }, $class
+   open my $fh, "<&=", $fd
+      or die "cannot open fd $fd as perl handle\n";
+
+   bless { fd => $fd, fh => $fh }, $class
 }
 
 =item $watch = $inotify->watch ($name, $mask[, $cb])
 
 Add a new watcher to the given notifier. The watcher will create events
 on the pathname C<$name> as given in C<$mask>, which can be any of the
-following constants (all exported by default) ORed together.
+following constants (all exported by default) ORed together. Constants
+unavailable on your system will evaluate to C<0>.
 
 "file" refers to any file system object in the watched object (always a
 directory), that is files, directories, symlinks, device nodes etc., while
@@ -213,12 +217,20 @@ Returns the file descriptor for this notify object. When in non-blocking
 mode, you are responsible for calling the C<poll> method when this file
 descriptor becomes ready for reading.
 
+=item $inotify->fh
+
+Similar to C<fileno>, but returns a perl file handle instead.
+
 =cut
 
 sub fileno {
    $_[0]{fd}
 }
 
+sub fh {
+   $_[0]{fh}
+}
+
 =item $inotify->blocking ($blocking)
 
 Clears ($blocking true) or sets ($blocking false) the C<O_NONBLOCK> flag on the file descriptor.
@@ -270,8 +282,6 @@ sub read {
    my @res;
 
    for (@ev) {
-      $_->{wd}=-1; $_->{mask} = IN_Q_OVERFLOW;#d#
-
       exists $self->{ignore}{$_->{wd}}
          and next; # watcher has been canceled
 
@@ -337,10 +347,6 @@ sub broadcast {
    }
 }
 
-sub DESTROY {
-   inotify_close $_[0]{fd}
-}
-
 =back
 
 =head2 The Linux::Inotify2::Event Class
